function [A_hat E_hat] = proxGradRPCA_ans(D,lambda,GT)
% D - Original video frames. size = (height * width) x number of frames in video
% lambda - Problem parameter - tradeoff between ||A||_{*} and ||E||_1
% GT - Groundtruth background image

[m,n] = size(D) ;

% initialization
X_k_A = zeros(m,n) ; X_k_E = zeros(m,n) ; % X^{k} = (A^{k},E^{k})
X_k1_A = zeros(m,n) ; X_k1_E = zeros(m,n) ; % X^{k+1} = (A^{k+1},E^{k+1})

funEvals = 1;
converged = 0;

%penalty parameter
mu_0 = norm(D);
mu_k = 0.99*mu_0 ;
mu_bar = 1e-9 * mu_0 ;

%termination parameters
tol = 1e-6;
maxEvals = 500;

while funEvals < maxEvals
    
    %implement optimal update of A
    
    %implement optimal update of E
        
    %calculate termination criteria
    diff = (X_k1_A - X_k_A) + (X_k1_E - X_k_E);
    stoppingCriterion = norm(diff,'fro')/(norm([X_k1_A,X_k1_E],'fro')) ;
    
    if stoppingCriterion <= tol
        %convergence
        converged = 1;
        break;
    end
    
    %calculate average PSNR over all frames
    PSNR(funEvals) = PeakSignaltoNoiseRatio(X_k_A,repmat(GT,[1 n]));
    disp(['Average PSNR = ' num2str((PSNR(funEvals)))]);
    
    %update variables
    X_k_A = X_k1_A ; 
    X_k_E = X_k1_E ;
        
    %relax the penalty parameter
    mu_k = max(0.9*mu_k,mu_bar) ;
    
    funEvals = funEvals + 1;
    
end

if ~converged && funEvals >= maxEvals
    disp('Maximum iterations reached') ;
end

A_hat = X_k_A ;
E_hat = X_k_E ;

plot(PSNR);

end

function P = pos(A)

P = A .* double( A > 0 );

end
